#!/bin/bash
#$ -cwd
#$ -j y
#$ -l h_data=32G,h_rt=24:00:00,highp
#$ -e ./OutFiles
#$ -o ./OutFiles
#$ -t 1-22:1

source ~/.bashrc

if [ ! $SGE_TASK_ID ]; then
    chr=$1
else
    chr=$SGE_TASK_ID
fi


ldir=/u/home/n/nmancuso/projects/covid19/
ddir=$ldir/data/
ssdir=$ddir/gwas/munged/
wdir=~/pasaniucdata/DATA/GTEXv8/GTEXv8_FUSION/weights/EUR/
lddir=~/pasaniucdata/DATA/LDSC_GRCh38/plink_files/

pwdir=$ddir/protein/

odir=$ldir/results/twas/
podir=$ldir/results/pwas/

GWAS=ANA_C2_V2_20200701
# ANA_C2_V2_20200626

gunzip $ssdir/${GWAS}/chr${chr}.tsv.gz

Rscript FUSION.assoc_test.R \
    --sumstats $ssdir/${GWAS}/chr${chr}.tsv \
    --out $odir/${GWAS}/gtexv8.whole_blood.chr${chr}.tsv \
    --weights $wdir/GTEXv8.Whole_Blood.nofilter.pos \
    --weights_dir $wdir/ \
    --ref_ld_chr $lddir/1000G.EUR.hg38. \
    --chr $chr

Rscript FUSION.assoc_test.R \
    --sumstats $ssdir/${GWAS}/chr${chr}.tsv \
    --out $odir/${GWAS}/gtexv8.lung.chr${chr}.tsv \
    --weights $wdir/GTEXv8.Lung.nofilter.pos \
    --weights_dir $wdir/ \
    --ref_ld_chr $lddir/1000G.EUR.hg38. \
    --chr $chr

Rscript FUSION.assoc_test.R \
    --sumstats $ssdir/${GWAS}/chr${chr}.tsv \
    --out $podir/${GWAS}/interval.chr${chr}.tsv \
    --weights $pwdir/INTERVAL.pos \
    --weights_dir $pwdir/ \
    --ref_ld_chr $lddir/1000G.EUR.hg38. \
    --chr $chr

gzip $ssdir/${GWAS}/chr${chr}.tsv
