library(tidyverse)
library(qqman)

# change to local directory here!
ldir <- ""

palette <- PNWColors::pnw_palette("Shuksan2", 5)
gtex_l <- 1
gtex_b <- 2
interval <- 3
gtex_sp_l <- 4
gtex_sp_b <- 5

df_i <- read_tsv(paste0(ldir, "/pwas/ANA_B2_V2_20200701/interval.all.tsv.gz")) %>%
            mutate(color = palette[interval])
tws_i <- 0.05 / nrow(df_i)

df_l <- read_tsv(paste0(ldir, "/twas/ANA_B2_V2_20200701/gtexv8.lung.all.tsv.gz")) %>%
            mutate(color = palette[gtex_l])
tws_l <- 0.05 / nrow(df_l)

df_b <- read_tsv(paste0(ldir, "/twas/ANA_B2_V2_20200701/gtexv8.whole_blood.all.tsv.gz")) %>%
            mutate(color = palette[gtex_b])
tws_b <- 0.05 / nrow(df_b)

df_sp_l <- read_tsv(paste0(ldir, "/sp_twas/ANA_B2_V2_20200701/gtexv8.lung.all.tsv.gz")) %>%
            mutate(color = palette[gtex_sp_l],
                   PANEL = paste0(PANEL, ".Splice"))
tws_sp_l <- 0.05 / nrow(df_sp_l)

df_sp_b <- read_tsv(paste0(ldir, "/sp_twas/ANA_B2_V2_20200701/gtexv8.whole_blood.all.tsv.gz")) %>%
            mutate(color = palette[gtex_sp_b],
                   PANEL = paste0(PANEL, ".Splice"))
tws_sp_b <- 0.05 / nrow(df_sp_b)


df_all <- bind_rows(list(df_i, df_l, df_b, df_sp_l, df_sp_b)) %>%
            select(panel = PANEL, chr = CHR, bp = P0, snp = FILE, z = TWAS.Z, p = TWAS.P)
tws <- 0.05 / nrow(df_all)

png("ana_b2.manhattan.all.png", width=7, height=3, units="in", res=100)
plot <- manhattan(df_all, chr = "chr", bp = "bp", snp = "snp", p = "p", suggestiveline=FALSE, genomewideline=-log10(tws), annotateTop=FALSE)
dev.off()

png("ana_b2.manhattan.interval.png", width=7, height=3, units="in", res=100)
plot <- manhattan(df_all %>% filter(panel == "INTERVAL"),
                  chr = "chr", bp = "bp", snp = "snp", p = "p", suggestiveline=FALSE, genomewideline=-log10(tws_i), annotateTop=FALSE)
dev.off()

png("ana_b2.manhattan.gtex.lung.png", width=7, height=3, units="in", res=100)
plot <- manhattan(df_all %>% filter(grepl("Lung", panel) & !grepl("Splice", panel)),
                  chr = "chr", bp = "bp", snp = "snp", p = "p", suggestiveline=FALSE, genomewideline=-log10(tws_l), annotateTop=FALSE)
dev.off()

png("ana_b2.manhattan.gtex.splice.lung.png", width=7, height=3, units="in", res=100)
plot <- manhattan(df_all %>% filter(grepl("Lung.Splice", panel)),
                  chr = "chr", bp = "bp", snp = "snp", p = "p", suggestiveline=FALSE, genomewideline=-log10(tws_sp_l), annotateTop=FALSE)

png("ana_b2.manhattan.gtex.whole_blood.png", width=7, height=3, units="in", res=100)
plot <- manhattan(df_all %>% filter(grepl("Whole", panel)),
                  chr = "chr", bp = "bp", snp = "snp", p = "p", suggestiveline=FALSE, genomewideline=-log10(tws_b), annotateTop=FALSE)
dev.off()

png("ana_b2.manhattan.gtex.splice.whole_blood.png", width=7, height=3, units="in", res=100)
plot <- manhattan(df_all %>% filter(grepl("Blood.Splice", panel)),
                  chr = "chr", bp = "bp", snp = "snp", p = "p", suggestiveline=FALSE, genomewideline=-log10(tws_sp_b), annotateTop=FALSE)
dev.off()
